{% for icon_name,icon_values in icons.items %}${{ icon_values.class_name }}: "{{ icon_values.utf8 }}";
{% endfor %}

@mixin include-icons(){
    {% for icon_name,icon_values in icons.items %}.{{ icon_values.class_name }}::before {
        content: ${{ icon_values.class_name }};
    }
    {% endfor %}
}